==> ejc-labor-impl-3.0.0-20221206.134811-185-sources.jar: com/ejianc/business/labor/service/IWorkRecordService.java <==
package com.ejianc.business.labor.service;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.ejianc.business.labor.vo.WorkRecordVO;
import com.ejianc.business.labor.vo.WorkerVO;
import com.ejianc.framework.core.response.CommonResponse;
import com.ejianc.framework.skeleton.template.IBaseService;
import com.ejianc.business.labor.bean.WorkRecordEntity;
import org.springframework.web.bind.annotation.RequestParam;

import java.text.ParseException;
import java.util.List;

/**
 * 用工记录
 * 
 * @author generator
 * 
 */
public interface IWorkRecordService extends IBaseService<WorkRecordEntity> {

    /**
     * 公司推送 设置
     *      teamId teamName orgTeamId orgTeamName
     *      workType workTypeName orgWorkType  orgWorkTypeName
     *      TeamInnerCode orgTeamInnerCode
     * 项目推送 设置
     *      teamId teamName projectTeamId projectTeamName
     *      workType workTypeName projectWorkType projectWorkTypeName
     *      TeamInnerCode projectTeamInnerCode
     * 设置来源 sourceFlag 来源（1自制-劳务进场单、2公司花名册、3邀请）
     * @param voList
     * @return
     */
    List<WorkRecordVO> insertWorkRecord(List<WorkRecordVO> voList);

    WorkRecordVO updateWorkRecord(WorkRecordVO vo);
    WorkRecordVO updateBatWorker(WorkRecordVO updateVO);



    CommonResponse<IPage<WorkRecordVO>> refWorkRecordDataToLab(
            int pageNumber,
            int pageSize,
            String relyCondition,
            String searchText,
            String condition,
            String searchObject) throws ParseException;
}

==> ejc-labor-impl-3.0.0-20250902.092924-346-sources.jar: com/ejianc/business/labor/service/IWorkRecordService.java <==
package com.ejianc.business.labor.service;

import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.ejianc.business.labor.vo.WorkRecordVO;
import com.ejianc.business.labor.vo.WorkerVO;
import com.ejianc.framework.core.response.CommonResponse;
import com.ejianc.framework.skeleton.template.IBaseService;
import com.ejianc.business.labor.bean.WorkRecordEntity;
import org.apache.ibatis.annotations.Param;
import org.springframework.web.bind.annotation.RequestParam;

import java.math.BigDecimal;
import java.text.ParseException;
import java.util.List;
import java.util.Map;

/**
 * 用工记录
 * 
 * @author generator
 * 
 */
public interface IWorkRecordService extends IBaseService<WorkRecordEntity> {

    /**
     * 公司推送 设置
     *      teamId teamName orgTeamId orgTeamName
     *      workType workTypeName orgWorkType  orgWorkTypeName
     *      TeamInnerCode orgTeamInnerCode
     * 项目推送 设置
     *      teamId teamName projectTeamId projectTeamName
     *      workType workTypeName projectWorkType projectWorkTypeName
     *      TeamInnerCode projectTeamInnerCode
     * 设置来源 sourceFlag 来源（1自制-劳务进场单、2公司花名册、3邀请）
     * @param voList
     * @return
     */
    List<WorkRecordVO> insertWorkRecord(List<WorkRecordVO> voList);

    WorkRecordVO updateWorkRecord(WorkRecordVO vo);
    WorkRecordVO updateBatWorker(WorkRecordVO updateVO);


    Integer updateWorkerTeamNameByTeamIdOrWorkerId(Long teamId, Long workerId);

    CommonResponse<IPage<WorkRecordVO>> refWorkRecordDataToLab(
            int pageNumber,
            int pageSize,
            String relyCondition,
            String searchText,
            String condition,
            String searchObject) throws ParseException;

    BigDecimal getLaborSalaryPayMny(Long projectId);

    List<Map<String, Object>> getLaborSalaryPayMnyByDate(@Param("projectId") Long projectId, @Param("startMonth") String startMonth, @Param("endMonth") String endMonth);

    JSONObject getLaborSalaryMny(List<Long> orgIds);
}
